@@ -2,7 +2,7 @@ import click
 from .tools import __dcrun
 from .tools import __dcexec
 from .tools import _execute_sql
-from . import cli, pass_config
+from .cli import cli, pass_config
 from .lib_clickhelpers import AliasedGroup
 
 
@@ -17,7 +17,7 @@ def lang(config):
 @click.argument("modules", nargs=-1, required=True)
 def export_i18n(lang, modules):
     modules = ",".join(modules)
-    __dcexec(["odoo", "/odoolib/export_i18n.py", lang, modules])
+    __dcexec(config, ["odoo", "/odoolib/export_i18n.py", lang, modules])
 
 
 @lang.command(name="list")
@@ -41,4 +41,4 @@ def get_all_langs(config):
 @click.argument("lang", required=False)
 @click.argument("po-file-path", required=True)
 def lang_import_i18n(lang, po_file_path):
-    __dcrun(["odoo", "/odoolib/import_i18n.py", lang, po_file_path])
+    __dcrun(config, ["odoo", "/odoolib/import_i18n.py", lang, po_file_path])
